capture log close
clear
clear matrix
log using "GenderInequality.log", replace
# delimit ;

*************************************************************************;
*************************************************************************;
* File to run models and calculate quantities of interest for the paper *;
*************** "Gender Inequality & Post-Conflict Peace"  **************;
*************************************************************************;
* Paper authors: DeMeritt & Nichols & Kelly                             *;
* Created by: JHRD                                                      *;
* Created on: 6 July 2011                                               *;
* Last edited on: 1 June 2014                                           *;
* Last edited by: JHRD                                                  *;
*************************************************************************;
*************************************************************************;

set mem 1000m;
set matsize 1000;
use "GenderInequality_master.dta";
stset time, id(warnum) failure(failed=1) exit(year==2003);

set seed 082281;
set more off;

*CODING NOTES;
                                                            ;
***** DV=peace spells following civil war (PRIO/Uppsala)    ;
***********=0 if peace continues                            ;
***********=1 if peace fails (relapse to civil war)         ;
                                                            ;
*****************************;
* GENDER EQUALITY VARIABLES *;
*****************************;
*(1) lit_ratio: ratio of female:male literacy rates (%)                                    ;
*(2) wip: \% of women in parliament                                                        ;
*(3) wilf: % of women in labor force (as a % of total force)                               ;
                                                                                           ;
*** NOTE: For each ratio, 1==perfect equality, >1 = female advantage, <1 = male advantage  ;
*** NOTE: Limit above list once we finalize GEQ vars to include                            ;


* BASELINE MODEL (all controls);
stcox settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;
                                                                                           ;
* RESTRICTED MODEL;
* Model including only GEQ variables;
stcox lit_ratio wip wilf, robust nolog strata(warcount) efron nohr;
quietly gen insample=1 if e(sample)==1;
stcox lit_ratio wip wilf, robust nolog strata(warcount) efron;

* FULLY-SPECIFIED MODEL;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;

* DISAGGREGATED BY PRESENCE/ABSENCE OF NEGOTIATED SETTLEMENT;

*Settlement;
stcox lit_ratio wip wilf wardur unpkotv2 lngdppc polity2 polity2sq ef efsq  if settle2==1, robust strata(warcount) nolog efron nohr ;
stcox lit_ratio wip wilf wardur unpkotv2 lngdppc polity2 polity2sq ef efsq  if settle2==1, robust strata(warcount) nolog efron ;

*No settlement;
*stcox lit_ratio wip wilf wardur unpkotv2 lngdppc polity2 polity2sq ef efsq  if settle2==0, robust strata(warcount) nolog efron nohr ;
*Above reports only two coefficients, no SEs due to collinearity among IVs. Repeat dropping wardur, lngdppc, and ef2 (the sources of the collinearity problems);
stcox lit_ratio wip wilf unpkotv2 polity2 polity2sq ef  if settle2==0, robust strata(warcount) nolog efron nohr ;
stcox lit_ratio wip wilf unpkotv2 polity2 polity2sq ef  if settle2==0, robust strata(warcount) nolog efron ;

*************** ;
* DIAGNOSTICS * ;
*************** ;

* Check Proportional Hazards Assumption (via Schoenfeld Residuals);
quietly{;

stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr schoenfeld(sc*) scaledsch(ssc*);
};
stphtest, detail;

*********************** ;
* SUBSTANTIVE EFFECTS * ;
*********************** ;
                        ;
quietly{;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);
*Cumulative Baseline Hazards across each # of previous wars;                     
graph twoway connected cumhazard time, by(warcount) c(J) sort;
                        
*Cumulative Baseline Hazard for Warcount==1;
graph twoway connected cumhazard time if warcount==1, c(J) sort;
};   

* NOTE that cumulative baseline hazards after a Cox model estimate  ;
* the baseline hazard rate GIVEN THAT ALL COVARIATES EQUAL ZERO.    ;
* We prefer to examine substantively-meaningful impacts, as follows.;

*Grab necessary elements of the beta and VCV matrices;
matrix b=e(b);
matrix V=e(V);
scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar b4=b[1,4];
scalar b5=b[1,5];
scalar b6=b[1,6];
scalar b7=b[1,7];
scalar b8=b[1,8];
scalar b9=b[1,9];
scalar b10=b[1,10];
scalar b11=b[1,11];
scalar list b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 ;

* Choose meaningful values for the covariates and set associated scalars;
tabstat lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq warcount if e(sample)==1, stat(p50);

scalar h_lit_ratio = .8881598;
scalar h_wip = 7.5;
scalar h_wilf = 37.39859;
scalar h_settle2 = 0;
scalar h_wardur = 4;
scalar h_unpkotv2 = 0;
scalar h_lngdppc = 8.052378;
scalar h_polity2 = 3;
scalar h_polity2sq = 49;
scalar h_ef = .3868;
scalar h_efsq = .1496142;

*** Cumulative Hazard | lit_ratio \in [min,max], all others at p50 *** ;

quietly{;
drop cumhazard;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);


scalar h_litratio = .3007433;
gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_lit_ratio =  1.004549;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);

*Compare hazard | lit at min to hazard | lit at max;
*graph twoway connected cumhazard2 cumhazard3 time if warcount==1, c(J J) sort;	
};
				
graph twoway scatter cumhazard2 cumhazard3 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clwidth(medium)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(3 4) size(small) label(1 "")
									 			label(2 "")
									 			label(3 "Minimum Lit. Ratio")
									 			label(4 "Maximum Lit. Ratio"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("Female:Male Literacy Ratio" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

graph export chazard_litrat.eps, replace;				
			

*** Cumulative Hazard | wip \in [min,max], all others at p50 *** ;
quietly{;
drop cumhazard* x_betahat*;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);


scalar h_lit_ratio = .8881598;
scalar h_wip = 0;

gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_wip = 35.1;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);
};

graph twoway scatter cumhazard2 cumhazard3 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clwidth(medthick)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(3 4) size(small) label(1 "")
									 			label(2 "")
									 			label(3 "Minimum % (0)")
									 			label(4 "Maximum % (35.1)"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("% Women in Parliament" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

graph export chazard_wip.eps, replace;	


*** Cumulative Hazard | wilf \in [min,max], all others at p50 ***;
quietly{;
drop cumhazard* x_betahat*;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);


scalar h_wip = 7.5;
scalar h_wilf = 10.45408;
gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_wilf = 53.58167;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);
};

graph twoway scatter cumhazard2 cumhazard3 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clwidth(medium)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(3 4) size(small) label(1 "")
									 			label(2 "")
									 			label(3 "Minimum % (10.5)")
									 			label(4 "Maximum % (53.6)"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("% Women in Labor Force" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

graph export chazard_wilf.eps, replace;	

*** Cumulative Hazard | all equality variables \in [min,max];
quietly{;
drop cumhazard* x_betahat*;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);


scalar h_litratio = .3007433;
scalar h_wip = 0;
scalar h_wilf = 10.45408;
gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_lit_ratio =  1.004549;
scalar h_wip = 35.1;
scalar h_wilf = 53.58167;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);
};

graph twoway scatter cumhazard2 cumhazard3 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clwidth(medthick)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(3 4) size(small) label(1 "")
									 			label(2 "")
									 			label(3 "Minimum Female Participation")
									 			label(4 "Maximum Female Participation"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("All Gender Participation Variables" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

graph export chazard_all.eps, replace;	

*** Cumulative Hazard | lit_ratio and wip \in [min,max], others at p50;
quietly{;
drop cumhazard* x_betahat*;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);

scalar h_wilf = 37.39859;
scalar h_litratio = .3007433;
scalar h_wip = 0;
gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_lit_ratio =  1.004549;
scalar h_wip = 35.1;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);
};

graph twoway scatter cumhazard2 cumhazard3 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clwidth(medium)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(3 4) size(small) label(1 "")
									 			label(2 "")
									 			label(3 "Minimum Female Participation")
									 			label(4 "Maximum Female Participation"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("Literacy Ratio & Women in Parliament" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

*graph export chazard_litratANDwip.eps, replace;

*** Cumulative Hazard | polity2 \in [min,max], polity2sq^2 \in [min,max], all others at p50 *** ;
quietly{;
drop cumhazard* x_betahat*;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);

scalar h_ef=.479;
scalar h_efsq=.229;
scalar h_polity2=-10;
scalar h_polity2sq=-100;
gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_polity2=10;
scalar h_polity2sq=100;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);
};

graph twoway scatter cumhazard2 cumhazard3 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clwidth(medium)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(3 4) size(small) label(1 "")
									 			label(2 "")
									 			label(3 "Minimum Democracy")
									 			label(4 "Maximum Democracy"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("Democracy" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

*graph export chazard_democ.eps, replace;

*** Cumulative Hazard | ef \in [min,max], ef^2 \in [min,max], all others at p50 *** ;
quietly{;
drop cumhazard* x_betahat*;
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr basechazard(cumhazard);

scalar h_lit_ratio=.8881598;
scalar h_wip=7.5;
scalar h_ef=.004;
scalar h_efsq=.000016;
gen x_betahat = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard2 = cumhazard*exp(x_betahat);

scalar h_ef=.479;
scalar h_efsq=.229;
gen x_betahat2 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard3 = cumhazard*exp(x_betahat2);

scalar h_ef=1;
scalar h_efsq=1;
gen x_betahat3 = b1*h_lit_ratio 
					+ b2*h_wip
					+ b3*h_wilf
					+ b4*h_settle2
					+ b5*h_wardur
					+ b6*h_unpkotv2
					+ b7*h_lngdppc
					+ b8*h_polity2
					+ b9*h_polity2sq
					+ b10*h_ef
					+ b11*h_efsq;
gen cumhazard4 = cumhazard*exp(x_betahat3);
};

graph twoway scatter cumhazard2 cumhazard3 cumhazard4 time if warcount==1 
		|| lowess cumhazard2 time if warcount==1, clpattern(solid) clwidth(medium) clcolor(black)
		|| lowess cumhazard3 time if warcount==1,  clpattern(dash_dot) clwidth(medium)  clcolor(black)
		|| lowess cumhazard4 time if warcount==1,  clpattern(dash) clwidth(medium)  clcolor(black)
		|| ,
			xlabel(, labsize(2.5))
			ylabel(0 1.1 2.2 3.3, labsize(2.5))
			xscale(noline)
			yscale(noline)
			legend(col(2) order(4 5 6) size(small) label(1 "")
									 			label(4 "Minimum")
									 			label(5 "Median Ethnic Fractionalization")
									 			label(6 "Maximum Ethnic Fractionalization"))
			yline(0, lcolor(black))
			title("", size(4))
			subtitle("Ethnic Fractionalization" "" "", size(3.5))
			xtitle(Time, size(3))
			xsca(titlegap(2))
			ysca(titlegap(2))
			ytitle("Cumulative Hazard", size(3))
			scheme(s2mono) graphregion(fcolor(white));

*graph export chazard_ethfrac.eps, replace;
							
***************************** ;
***************************** ;
* Stuff for online appendix * ;
***************************** ;
***************************** ;

*** Alternative measures of economic inclusion;
	* Replace wilf with female:male labor ratio;
stcox lit_ratio wip lab_ratio, robust strata(warcount) nolog efron nohr;
stcox lit_ratio wip lab_ratio, robust strata(warcount) nolog efron;

stcox lit_ratio wip lab_ratio settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr;
stcox lit_ratio wip lab_ratio settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;

** Alternative measures of social inclusion;
	*(1) Replace lit_ratio with female:male life expectency ratio;
stcox lifex_ratio wip wilf, robust strata(warcount) nolog efron nohr;
stcox lifex_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq if insample==1, robust strata(warcount) nolog efron nohr;
	*(2) Replace lit_ratio with fertility rate;
stcox fertile wip wilf if insample==1, robust strata(warcount) nolog efron nohr;
*stcox fertile wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq if insample==1, robust strata(warcount) nolog efron nohr;
*Fertility rate violates PH assumption. Interact with time and rerun;
gen fertiletime=fertile*_t;
stcox fertiletime wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq if insample==1, robust strata(warcount) nolog efron nohr;
	*(3) Replace lit_ratio with female:male secondary educ ratio;
stcox educ_ratio wip wilf, robust strata(warcount) nolog efron nohr;
stcox educ_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq if insample==1, robust strata(warcount) nolog efron nohr;
	

* Correlation among all IVs;
	quietly{;
	stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;
	corr lit_ratio wip wilf settle2 unpkotv2 wardur lngdppc polity2 polity2sq ef efsq if e(sample)==1;

* Robustness check: Use Breslow method for ties;
	*PARTIAL MODELS;
	* Model capturing elements of civil war;
	stcox settle2 wardur unpkotv2, robust strata(warcount) nolog;
	* Model capturing underlying social, econ and political problems that led to war;
	stcox lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog;
	* Model including only GEQ variables;
	stcox lit_ratio wip wilf, robust nolog strata(warcount);
	* BASELINE MODEL (all controls);
	stcox settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog;
	* FULLY-SPECIFIED MODEL;
	stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog;

* Robustness check: Replace lnGDPpc with IMR;
	* NOTE: corr(lit_ratio, imr) is quite high. Report with and without IMR included;
	corr lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc imr polity2 polity2sq ef efsq;
	corr lit_ratio imr;
	stcox lit_ratio wip wilf settle2 wardur unpkotv2 polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr;
	stcox lit_ratio wip wilf settle2 wardur unpkotv2 polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;

	stcox wip wilf settle2 wardur unpkotv2 imr polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr;
	stcox wip wilf settle2 wardur unpkotv2 imr polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;

	stcox lit_ratio wip wilf settle2 wardur unpkotv2 imr polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr;
	stcox lit_ratio wip wilf settle2 wardur unpkotv2 imr polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;

* Robustness check (for endogeneity): Lag gender variables;
gen lccode=ccode[_n-1];
gen litratl1=lit_ratio[_n-1];
replace litratl1=. if ccode~=lccode;
gen wipl1=wip[_n-1];
replace wipl1=. if ccode~=lccode;
gen wilfl1=wilf[_n-1];
replace wilfl1=. if ccode~=lccode;
gen settle2l1=settle2[_n-1];
replace settle2l1=. if ccode~=lccode;
gen wardurl1=wardur[_n-1];
replace wardurl1=. if ccode~=lccode;
gen unpkotv2l1=unpkotv2[_n-1];
replace unpkotv2l1=. if ccode~=lccode;
gen lngdppcl1=lngdppc[_n-1];
replace lngdppcl1=. if ccode~=lccode;
gen polity2l1=polity2[_n-1];
replace polity2l1=. if ccode~=lccode;
gen polity2sql1=polity2sq[_n-1];
replace polity2sql1=. if ccode~=lccode;
gen efl1=ef[_n-1];
replace efl1=. if ccode~=lccode;
gen efsql1=efsq[_n-1];
replace efsql1=. if ccode~=lccode;
gen imrl1=imr[_n-1];
replace imrl1=. if ccode~=lccode;

stcox litratl1 wipl1 wilfl1, robust strata(warcount) nolog efron;
stcox litratl1 wipl1 wilfl1 settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;
stcox litratl1 wip wilfl1 settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron;
};

*With PRIO (type=3&4) instead of Sambanis CW;
quietly{;
clear;
clear matrix;
# delimit ;

set mem 1000m;
set matsize 1000;
use "DKN.master.withprio.dta";
drop _d _t _t0;
stset time, id(warnum) failure(priofailed=1) exit(year==2003);

set seed 082281;
set more off;
 };
                                                                                    ;
* RESTRICTED MODEL;
* Model including only GEQ variables;
*drop sc* ssc*;
stcox lit_ratio wip wilf, nolog  robust strata(warcount) efron nohr;
stcox lit_ratio wip wilf, nolog  robust strata(warcount) efron ;

quietly{;
* FULLY-SPECIFIED MODEL (with check for PH assumption);
stcox lit_ratio wip wilf settle2 wardur unpkotv2 lngdppc polity2 polity2sq ef efsq, robust strata(warcount) nolog efron nohr schoenfeld(sc*) scaledsch(ssc*);
};

stphtest, detail;

** In fully-specified model, these vars violate the PH Assumption: wip, wilf, settle2, unpkotv2, and polity2sq;
*interact each with time;
quietly{;
gen wiptime=wip*_t;
gen wilftime=wilf*_t;
gen settle2time=settle2*_t;
gen unpkotv2time=unpkotv2*_t;
gen polity2sqtime=polity2sq*_t;
};

*re-run model with corrected regressors;
stcox lit_ratio wiptime wilftime settle2time wardur unpkotv2time lngdppc polity2 polity2sqtime ef efsq, robust strata(warcount) nolog efron nohr;
stcox lit_ratio wiptime wilftime settle2time wardur unpkotv2time lngdppc polity2 polity2sqtime ef efsq, robust strata(warcount) nolog efron;


log close;
